@@ -18,7 +18,6 @@ from qctrl.builders.type_registry import TypeOverrideMixin
 class ComplexArrayEntryHandler(  # pylint:disable=too-many-ancestors
     NamedObjectHandler, TypeOverrideMixin
 ):  # pylint:disable=too-few-public-methods
-    """Custom scalar handler for ComplexArrayEntry
-    """
+    """Custom scalar handler for ComplexArrayEntry"""
 
     _object_name = "ComplexArrayEntry"
