@@ -195,8 +195,7 @@ class GraphQLEnvironment:
 
     @staticmethod
     def format_query_payload_dict(data: Dict[str, Any]) -> str:
-        """Formats a key-value dictionary for a query.
-        """
+        """Formats a key-value dictionary for a query."""
         values = []
 
         for key, value in data.items():
@@ -206,7 +205,6 @@ class GraphQLEnvironment:
 
     @staticmethod
     def format_query_selection_fields(fields: List[str]) -> str:
-        """Formats a list of values for a query.
-        """
+        """Formats a list of values for a query."""
         # e.g '{ modelId name status errors progress }'
         return "{ %s }" % (" ".join(fields))
