@@ -207,7 +207,12 @@ def activity(
     gql_env = create_environment(gql_api)
 
     activity_monitor = ActivityMonitor(
-        gql_api, gql_env, limit=limit, offset=offset, status=status, action_type=type,
+        gql_api,
+        gql_env,
+        limit=limit,
+        offset=offset,
+        status=status,
+        action_type=type,
     )
 
     if options:
